API Reference
=============

This section provides detailed API documentation for the tailestim package.

.. toctree::
   :maxdepth: 2

   base
   estimators/index
   estimator-set
   result
   data

